<?php

namespace App;

use Illuminate\Database\Eloquent\Model;

class PurchaseLine extends Model
{
    /**
     * The attributes that aren't mass assignable.
     *
     * @var array
     */
    protected $guarded = ['id'];

    public function transaction()
    {
        return $this->belongsTo(\App\Transaction::class);
    }

    public function product()
    {
        return $this->belongsTo(\App\Product::class, 'product_id');
    }

    public function variations()
    {
        return $this->belongsTo(\App\Variation::class, 'variation_id');
    }

    /**
     * Set the quantity.
     *
     * @param string $value
     * @return float $value
     */
    public function getQuantityAttribute($value)
    {
        return (float)$value;
    }

    /**
     * Get the unit associated with the purchase line.
     */
    public function sub_unit()
    {
        return $this->belongsTo(\App\Unit::class, 'sub_unit_id');
    }

    /**
     * Give the quantity remaining for a particular
     * purchase line.
     *
     * @return float $value
     */
    public function getQuantityRemainingAttribute()
    {
        return (float)($this->quantity - $this->quantity_used);
    }

    /**
     * Give the sum of quantity sold, adjusted, returned.
     *
     * @return float $value
     */
    public function getQuantityUsedAttribute()
    {
        return (float)($this->quantity_sold + $this->quantity_adjusted + $this->quantity_returned + $this->mfg_quantity_used);
    }

    public function line_tax()
    {
        return $this->belongsTo(\App\TaxRate::class, 'tax_id');
    }

    public function getDiscountAmountAttribute()
    {
        if ($this->discount) {
            return ($this->discount_method == 'fixed') ? $this->discount : ($this->discount * $this->purchase_price) / 100;
        }
        return 0;
    }

    public function getPurchasePriceIncTaxAttribute($value)
    {
//        $item_tax = 0;
//        if ($this->line_tax) {
//            $item_tax = ($this->line_tax->amount * ($this->purchase_price - $this->discount_amount)) / 100;
//        }
//
        return $this->purchase_price + $this->item_tax;
    }

    public function getUnitCostAttribute($value)
    {
//        $item_tax = 0;
//        if ($this->line_tax) {
//            $item_tax = ($this->line_tax->amount * ($this->purchase_price - $this->discount_amount)) / 100;
//        }
//
        return $this->purchase_price + $this->item_tax-$this->discount_amount;
    }

    public function getItemTaxAttribute($value)
    {
        if ($this->line_tax) {
            return ($this->line_tax->amount * $this->purchase_price) / 100;
        }
        return 0;
    }

//

    public function purchase_order_line()
    {
        return $this->belongsTo(\App\PurchaseLine::class, 'purchase_order_line_id');
    }

    public function purchase_requisition_line()
    {
        return $this->belongsTo(\App\PurchaseLine::class, 'purchase_requisition_line_id');
    }
}
