<?php


namespace App\Utils;

use App\AccountTransaction;
use App\Business;
use App\BusinessLocation;
use App\CashDenomination;
use App\Contact;
use App\Currency;
use App\Events\TransactionPaymentAdded;
use App\Events\TransactionPaymentDeleted;
use App\Events\TransactionPaymentUpdated;
use App\Exceptions\AdvanceBalanceNotAvailable;
use App\Exceptions\PurchaseSellMismatch;
use App\InvoiceScheme;
use App\Product;
use App\PurchaseLine;
use App\Restaurant\ResTable;
use App\TaxRate;
use App\Transaction;
use App\TransactionPayment;
use App\TransactionSellLine;
use App\TransactionSellLinesPurchaseLines;
use App\Variation;
use App\VariationLocationDetails;
use Illuminate\Support\Facades\DB;
use Illuminate\Support\Str;
use App\Utils\Stock;
use App\StockEntry;
use App\StockItems;
use App\StockEntryItemLocations;
use App\Utils\StockEntryLocations;




class StockEntryUtils extends Util
{
        public function adjustStockEntryReceived($before_status, $transaction, $delete_purchase_lines, $user_id, $request)
        {
            if($transaction->status == 'pending' || $transaction->status == 'ordered'){
               //here we delete entry
               try{
                    $stock_entry = StockEntry::where('transaction_id',$transaction->id)->first();
                    if(empty($stock_entry)){
                        return;
                    }
                    $stock_entry->stockitems()->delete();
                    $stock_entry->delete();
                    
               }catch(e){
                  // path 
               }
            }
            if($transaction->status == 'received'){
                $tmp_products = array();
                if($before_status != 'received'){
                    foreach($request->input() as $p){
                        if(is_array($p)){
                        $tmp_products = $p;
                    }
                    }
                    $stock_entry = StockEntry::create([
                        'user_id' => $user_id,
                        'transaction_id' => $transaction->id,
                        'transaction_type' => 'OPEN_STOCK',
                        'reference' => $transaction->ref_no,
                        'descriptions' => $transaction->additional_notes,
                        'date' => $transaction->transaction_date,
                        'time' => $transaction->created_at,
                        'created_at' => $transaction->created_at,
                        'updated_at' => $transaction->created_at,
                        'exchange_rate_id' => $transaction->exchange_rate
                    ]);
                    $stock_entry->entry_location()->create([
                        'type' => 'ORIGIN',
                        'store_id' => $transaction->business_id
                    ]);
                    for($i = 0; $i < count($tmp_products); $i++){
                        $product = $tmp_products[$i];
                        $stock_entry->stockitems()->create(
                            [
                                'value_added_tax_id' => $transaction->tax_id,
                                'price_structure_id' => NULL,
                                'valuation_rate' => $transaction->exchange_rate,
                                'tax_method' => $request->input('vat'),
                                'unit_of_measurement_id' => $product['product_unit_id'],
                                'item_id'  => $product['product_id'],
                                'quantity' => $product['quantity'],
                                'rate' => $request->input('rate'),
                                'discount' => $product['discount_percent'],
                                'discount_method' => $product['discount_method'],
                                'descriptions' => $transaction->additional_notes
                            ]
                        );
                    }
                }
            }
        }
}